@@ -5,9 +5,11 @@ use lib qw(blib/lib blib/arch);
 use Imager;
 use Imager::Plot;
 
+Imager::Font->priorities(qw(w32 ft2 tt t1));
+
 $plot = Imager::Plot->new(Width  => 550,
 			  Height => 350,
-			  GlobalFont => 'ImUgly.ttf');
+			  GlobalFont => get_font() );
 
 my @X = 0..100;
 my @Y = map { sin($_/10) } @X;
@@ -46,7 +48,6 @@ $Axis->{Xformat} = sub {
   my $t = sprintf("%.0f",$_[0]/10);
   $t = 0 if $t<0;
   $t = 10 if $t>10;
-  print "$_[0] $t\n";
   return $n[$t];
 };
 
@@ -58,3 +59,14 @@ $plot->Render(Image => $img, Xoff => 40, Yoff => 370);
 
 mkdir("sampleout", 0777) unless -d "sampleout";
 $img->write(file => "sampleout/sample5.ppm");
+
+
+sub get_font {
+  my %opts = (size=>12, color=>Imager::Color->new('black'));
+
+  my $font = Imager::Font->new(file=>"ImUgly.ttf", %opts)
+    || Imager::Font->new(file=>"./dcr10.pfb", %opts);
+  die "Couldn't load any font!\n" unless $font;
+
+  return $font;
+}
